<?php
declare(strict_types=1);

namespace Intergo\LaravelAuthMiddleware\Services\Microservices;

use Intergo\AuthClient\AbstractAuthService;
use Intergo\BaseClient\Responses\BaseResponseInterface;
use Intergo\LaravelAuthMiddleware\Events\UserLoggedIn;
use Intergo\Log\Contracts\LoggingFieldsEnum;
use Intergo\Log\GrayLogHandler;

class AuthService extends AbstractAuthService
{
    const SITE = 'smsto';
    const SUCCESS = 'success';
    const FAILED = 'failed';
    private GrayLogHandler $grayLogger;

    /**
     * AuthService constructor.
     */
    public function __construct()
    {
        $this->grayLogger = app(GrayLogHandler::class);

        parent::__construct(
            config('auth-middleware.site'),
            config('auth-middleware.url'),
            config('auth-middleware.jwt_secret'),
            config('auth-middleware.auth_trace_id')
        );
    }
    /**
     * @param string $action
     * @param $email
     * @param $ip
     * @param BaseResponseInterface $result
     * @return BaseResponseInterface
     */
    public function response(string $action, $email, $ip, BaseResponseInterface $result): BaseResponseInterface
    {
        if ($result->isSuccessful()) {
            $auth_result = self::SUCCESS;
            $this->grayLogger->info("{$action}:{$auth_result}",
                compact(LoggingFieldsEnum::EMAIL, LoggingFieldsEnum::IP_ADDRESS, LoggingFieldsEnum::AUTH_RESULT));
        } else {
            $auth_result = self::FAILED;
            $this->grayLogger->error("{$action}:{$auth_result}", [
                LoggingFieldsEnum::AUTH_RESULT => $auth_result,
                LoggingFieldsEnum::EMAIL => $email,
                LoggingFieldsEnum::IP_ADDRESS => $ip,
                LoggingFieldsEnum::RESPONSE_MESSAGE => $result->getMessage(),
                LoggingFieldsEnum::RESPONSE_DATA => $result->getData()['info'] ?? $result->getData(),
                LoggingFieldsEnum::RESPONSE_CODE => $result->getData()['errorCode'] ?? ''
            ]);
        }
        return $result;
    }
    public function storeJWT($authToken, $authUser): void
    {
        UserLoggedIn::dispatch($authToken, $authUser);
    }
}
